const {constants, log, helpers} = require('utils-nxg-cg');
const {objectXmlJson,objectJsonXml} = require('./objects');
const {transformXmlJson,transformJsonXml} = require('./transforms');
const {isObjectValid} = require("utils-nxg-cg/utils/helpers");
/**
 * Method for process the data user and execute query single or batch by transactions
 * @param msg
 * @param cfg
 * @param test
 * @returns {Promise<array|object>}
 */

 const processXmlJson  = async (msg = {}, cfg = {}, test = false) => {
  
        try {
            const {data} = msg;

            let properties = {...objectXmlJson};          

            if (!test && !data) {
                throw Error(`${constants.ERROR_PROPERTY} data`);
            }
            const valid = await helpers.validProperties(properties, data, cfg);

            if (valid) {
                if (!helpers.validateBase64(properties.content))
                throw Error(`${constants.ERROR_WITH_PROPERTY} content is not base64`);
                const result = await transformXmlJson(properties);
                return result;
            }
        } catch (e) {
            log.error(e);
            throw Error(e);
        }
    
};

const processJsonXml  = async (msg = {}, cfg = {}, test = false) => {
  
    try {
        const {data} = msg;

        let properties = {...objectJsonXml};          

        if (!test && !data) {
            throw Error(`${constants.ERROR_PROPERTY} data`);
        }
        const valid = await helpers.validProperties(properties, data, cfg);

        if (valid) {
            if(!isObjectValid(properties.content))
            throw Error(constants.ERROR_JSON_FORMAT);
            const result = await transformJsonXml(properties);
            return result;
        }
    } catch (e) {
        log.error(e);
        throw Error(e);
    }

};

module.exports = {processXmlJson,processJsonXml};